==> attal_0.8.orig.tar.gz: attal-0.8/libCommon/genericRessources.h <==
/****************************************************************
**
** Attal : Lords of Doom
**
** genericRessources.h
** Management of ressources infos
**
** Version : $Id: genericRessources.h,v 1.1.1.1 2003/06/15 19:02:08 audoux Exp $
**
** Author(s) : Pascal Audoux
**
** Date : 03/01/2001
**
** Licence :    
**	This program is free software; you can redistribute it and/or modify
**   	it under the terms of the GNU General Public License as published by
**     	the Free Software Foundation; either version 2, or (at your option)
**      any later version.
**
**	This program is distributed in the hope that it will be useful,
** 	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**	GNU General Public License for more details.
**
****************************************************************/

 
#ifndef GENERICRESSOURCES_H
#define GENERICRESSOURCES_H
 
 
// generic include files
// include files for QT
#include <qstring.h>
#include <qlist.h>
// application specific include files
 
class QListBox;
 
/*              ------------------------------
 *                         GenericRessources
 *              ------------------------------ */



/** comment for the class */
class GenericRessources : public QList<QString>
{
 
public:
	/** Construtor : load ressources info from 'filename' */
	GenericRessources();
	
	/** Destructor (for pointer) */
	virtual ~GenericRessources();	
	
	/** Initializes ressources */
	void init();
	
	bool save();

	void update( int num, QString val );
	
	/** Return the ressources 'num' if possible */
	QString getRessource( uint num );
};
 
#endif // GENERICRESSOURCES_H

==> attal_0.9.2.orig.tar.gz: attal-0.9.2/libCommon/genericRessources.h <==
/****************************************************************
**
** Attal : Lords of Doom
**
** genericRessources.h
** Management of ressources infos
**
** Version : $Id: genericRessources.h,v 1.3 2004/07/31 19:29:46 audoux Exp $
**
** Author(s) : Pascal Audoux
**
** Date : 03/01/2001
**
** Licence :    
**	This program is free software; you can redistribute it and/or modify
**   	it under the terms of the GNU General Public License as published by
**     	the Free Software Foundation; either version 2, or (at your option)
**      any later version.
**
**	This program is distributed in the hope that it will be useful,
** 	but WITHOUT ANY WARRANTY; without even the implied warranty of
**	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
**	GNU General Public License for more details.
**
****************************************************************/

 
#ifndef GENERICRESSOURCES_H
#define GENERICRESSOURCES_H
 
 
// generic include files
// include files for QT
#include <qptrlist.h>
#include <qstring.h>
// application specific include files
 
class QListBox;
 
/*              ------------------------------
 *                         GenericRessources
 *              ------------------------------ */



/** comment for the class */
class GenericRessources : public QPtrList<QString>
{
 
public:
	/** Construtor : load ressources info from 'filename' */
	GenericRessources();
	
	/** Destructor (for pointer) */
	virtual ~GenericRessources();	
	
	/** Initializes ressources */
	bool init();
	
	bool save();

	void update( int num, QString val );
	
	/** Return the ressources 'num' if possible */
	QString getRessource( uint num );
};
 
#endif // GENERICRESSOURCES_H
